@@ -5,7 +5,7 @@ use strict;
 use warnings;
 use Carp;
 
-our $VERSION = '0.22';
+our $VERSION = '0.23';
 
 sub new {
     my ( $class, $container ) = @_;
@@ -198,9 +198,9 @@ sub _collect_garbage {
         elsif ( $object->get('ENTRY')->equals($ROUTE) ) {
             next;
         }
-
         else {
-            confess "\nI don't know what this is:\n", $object->dump();
+            warn "\nunknown object:\n", $object->dump();
+            next;
         }
     }
 
